@@ -2,10 +2,11 @@ package Log::Dispatch::Email::Mailer;
 # ABSTRACT: Log::Dispatch::Email subclass that sends mail using Email::Mailer
 
 use 5.014;
-use exact 'Log::Dispatch::Email';
+use exact;
+use base 'Log::Dispatch::Email';
 use Email::Mailer 1.09;
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 sub _params {
     my %params = @_;
@@ -65,7 +66,7 @@ Log::Dispatch::Email::Mailer - Log::Dispatch::Email subclass that sends mail usi
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =for markdown [![test](https://github.com/gryphonshafer/Log-Dispatch-Email-Mailer/workflows/test/badge.svg)](https://github.com/gryphonshafer/Log-Dispatch-Email-Mailer/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Log-Dispatch-Email-Mailer/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Log-Dispatch-Email-Mailer)
